Repository: flex-sdk
Updated Branches:
  refs/heads/develop 636859085 -> 145743606


Update jenkins script with new FP versions

The LTS version was bumped from 13 to 18 by Adobe:

http://blogs.adobe.com/flashplayer/2015/05/upcoming-changes-to-flash-players-extended-support-release-2.html

And obviously version 16 is no longer the most up-to-date consumer version ;-)

Signed-off-by: Erik de Bruin <e...@ixsoftware.nl>


Project: http://git-wip-us.apache.org/repos/asf/flex-sdk/repo
Commit: http://git-wip-us.apache.org/repos/asf/flex-sdk/commit/14574360
Tree: http://git-wip-us.apache.org/repos/asf/flex-sdk/tree/14574360
Diff: http://git-wip-us.apache.org/repos/asf/flex-sdk/diff/14574360

Branch: refs/heads/develop
Commit: 145743606d448e256f3f5371666782cf9c0e8482
Parents: 6368590
Author: Erik de Bruin <e...@ixsoftware.nl>
Authored: Fri Sep 25 09:31:48 2015 +0200
Committer: Erik de Bruin <e...@ixsoftware.nl>
Committed: Fri Sep 25 09:31:48 2015 +0200

----------------------------------------------------------------------
 mustella/jenkins.sh | 26 +++++++++++++-------------
 1 file changed, 13 insertions(+), 13 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/14574360/mustella/jenkins.sh
----------------------------------------------------------------------
diff --git a/mustella/jenkins.sh b/mustella/jenkins.sh
index 209bef7..6d716bb 100755
--- a/mustella/jenkins.sh
+++ b/mustella/jenkins.sh
@@ -50,8 +50,8 @@ fi
 # Toggle between versions:
 # 11.1 is the default version
 # 11.7 is a much used version?
 # 13 is the current "long term support" version
 # 16 is the beta and/or current version
 # Note: the previous release and current beta versions of AIR are both '4',
 #       so to make the distinction, the beta version is '4.01' on the VM
 if [ "$FLASH_VERSION" == "11.1" ]
@@ -61,14 +61,14 @@ then
   AIR_SDK_DIR=3.7
 elif [ "$FLASH_VERSION" == "11.7" ]
 then
-  FLASH_VERSION=13.0
-  AIR_VERSION=4.0
-  AIR_SDK_DIR=4.0
-elif [ "$FLASH_VERSION" == "13.0" ]
+  FLASH_VERSION=18.0
+  AIR_VERSION=18.0
+  AIR_SDK_DIR=18.0
+elif [ "$FLASH_VERSION" == "18.0" ]
 then
-  FLASH_VERSION=16.0
-  AIR_VERSION=16
-  AIR_SDK_DIR=16
+  FLASH_VERSION=19.0
+  AIR_VERSION=19
+  AIR_SDK_DIR=19
 else
   FLASH_VERSION=11.1
   AIR_VERSION=3.7
@@ -90,11 +90,11 @@ case "$FLASH_VERSION" in
   11.7)
     export 
FLASHPLAYER_DEBUGGER="C:\\ApacheFlex\\dependencies\\FlashPlayer_Debug\\flashplayer11_7r700_232_win_sa_debug.exe"
   ;;
-  13.0)
-    export 
FLASHPLAYER_DEBUGGER="C:\\ApacheFlex\\dependencies\\FlashPlayer_Debug\\flashplayer13_0r0_214_win_sa_debug.exe"
+  18.0)
+    export 
FLASHPLAYER_DEBUGGER="C:\\ApacheFlex\\dependencies\\FlashPlayer_Debug\\flashplayer_18_sa_debug.exe"
   ;;
-  16.0)
-    export 
FLASHPLAYER_DEBUGGER="C:\\ApacheFlex\\dependencies\\FlashPlayer_Debug\\flashplayer_16_sa_debug.exe"
+  19.0)
+    export 
FLASHPLAYER_DEBUGGER="C:\\ApacheFlex\\dependencies\\FlashPlayer_Debug\\flashplayer_19_sa_debug.exe"
   ;;
   *)
@@ -50,8 +50,8 @@ fi
 # 11.1 is the default version
 # 11.7 is a much used version?
-# 13 is the current "long term support" version
-# 16 is the beta and/or current version
+# 18 is the current "long term support" version
+# 19 is the current "consumer" version
 # Note: the previous release and current beta versions of AIR are both '4',
 #       so to make the distinction, the beta version is '4.01' on the VM
     echo "No valid Flash Player Debugger variable value could be parsed."

Reply via email to